==> perl-5.36.1-r3-1.gpkg.tar: image/usr/lib/perl5/5.36/hppa1.1-linux/CORE/patchlevel-gentoo.h <==
,"0001-Fix-hpux-hints.patch"
,"- Fix hpux hints"
,"0002-aix-gcc-detection-and-shared-library-soname-support.patch"
,"- aix gcc detection and shared library soname support"
,"0003-cpan-ExtUtils-MakeMaker-drop-PORTAGE_TMPDIR-from-LD_.patch"
,"- cpan/ExtUtils-MakeMaker: drop $PORTAGE_TMPDIR from LD_RUN_PATH"
,"- Bug: https://bugs.gentoo.org/105054"
,"0004-Remove-rpath-and-append-LDFLAGS-to-lddlflags.patch"
,"- Remove -rpath and append LDFLAGS to lddlflags"
,"0005-Add-headers-for-opensolaris.patch"
,"- Add headers for opensolaris"
,"0006-List-packaged-patches-in-patchlevel.h.patch"
,"- List packaged patches for perl-5.36.1-r3(perl-5.36.0-patches-1) in patchlevel.h"
,"- Bug: https://bugs.debian.org/567489"
,"0007-Cleanup-PATH-and-shrpenv.patch"
,"- Cleanup PATH and shrpenv"
,"0008-Tweak-enc2xs-to-follow-symlinks-and-ignore-missing-I.patch"
,"- Tweak enc2xs to follow symlinks and ignore missing @INC directories."
,"- Bug: https://bugs.debian.org/290336"
,"0009-darwin-Use-CC-to-link.patch"
,"- darwin: Use $CC to link"
,"- Bug: https://bugs.gentoo.org/297751"
,"0010-Provide-a-sensible-INSTALLDIRS-default-for-modules-i.patch"
,"- Provide a sensible INSTALLDIRS default for modules installed from CPAN."
,"0011-Fix-interix-hints.patch"
,"- Fix interix hints"
,"0012-Set-libperl-soname.patch"
,"- Set libperl soname"
,"- Bug: https://bugs.gentoo.org/286840"
,"0013-Add-etc-perl-to-INC.patch"
,"- Add /etc/perl to @INC"
,"0014-cpan-ExtUtils-MakeMaker-remove-targets-that-generate.patch"
,"- cpan/ExtUtils-MakeMaker: remove targets that generate perllocal.pod"
,"0015-Don-t-force-fstack-protector-on-everyone.patch"
,"- Don't force -fstack-protector on everyone"
,"- Bug: https://bugs.gentoo.org/348557"
,"0016-Do-not-set-custom-CFLAGS-in-cpan-Digest-SHA.patch"
,"- Do not set custom CFLAGS in cpan/Digest-SHA"
,"- Bug: https://bugs.gentoo.org/506818"
,"0017-Configure-Don-t-include-sources-in-usr-local-for-com.patch"
,"- Configure: Don't include sources in /usr/local/ for compiling perl"
,"0018-cpan-IO-Socket-IP-Disable-network-tests.patch"
,"- cpan/IO-Socket-IP: Disable network tests"
,"0019-Fix-EUMM-podlocal-tests.patch"
,"- Fix EUMM podlocal tests"
,"0020-Skip-auto-linking-nsl-and-cl.patch"
,"- Skip auto-linking nsl and cl"
,"- Bug: https://rt.perl.org/Public/Bug/Display.html?id=13148"
,"0021-Disable-porting-tests-which-create-fun-false-failure.patch"
,"- Disable porting tests which create fun false-failures all over travis"
,"0022-Disable-PathTools-tests-which-fails-under-sandboxing.patch"
,"- Disable PathTools tests which fails under sandboxing"
,"- Bug: https://bugs.gentoo.org/645084"
,"0023-Fix-CPAN-FirstTime-defaults-with-nonexisting-site-di.patch"
,"- Fix CPAN::FirstTime defaults with nonexisting site dirs if a parent is writable"
,"- Bug: https://bugs.debian.org/688842"
,"0024-Pass-LD-settings-through-to-subdirectories.patch"
,"- Pass LD settings through to subdirectories"
,"- Bug: https://bugs.debian.org/758471"
,"0025-Memoize-Storable-respect-nstore-option-not-respected.patch"
,"- Memoize::Storable: respect 'nstore' option not respected"
,"- Bug: https://bugs.debian.org/587650"
,"- Bug: https://rt.cpan.org/Public/Bug/Display.html?id=77790"
,"0026-Better-errors-for-man-pages-from-standard-input.patch"
,"- Better errors for man pages from standard input"
,"- Bug: https://bugs.debian.org/777405"
,"0027-Respect-umask-during-installation.patch"
,"- Respect umask during installation"
,"0028-Document-that-CCFLAGS-should-include-Config-ccflags.patch"
,"- Document that CCFLAGS should include $Config{ccflags}"
,"- Bug: https://bugs.debian.org/628522"
,"- Bug: https://rt.cpan.org/Public/Bug/Display.html?id=68613"
,"0029-Fix-parallel-building.patch"
,"- Fix parallel building"
,"0030-Add-support-for-Dgentoolibdirs.patch"
,"- Add support for -Dgentoolibdirs"
,"0111-5.36.1-http-tiny.patch"
,"- Enable certificate checking in HTTP::Tiny by default"
,"- Bug: https://bugs.gentoo.org/905296"
,"- Bug: https://bugs.debian.org/954089"

==> perl-5.38.2-r1-1.gpkg.tar: image/usr/lib/perl5/5.38/hppa2.0-linux/CORE/patchlevel-gentoo.h <==
,"0001-Fix-hpux-hints.patch"
,"- Fix hpux hints"
,"0002-aix-gcc-detection-and-shared-library-soname-support.patch"
,"- aix gcc detection and shared library soname support"
,"0003-cpan-ExtUtils-MakeMaker-drop-PORTAGE_TMPDIR-from-LD_.patch"
,"- cpan/ExtUtils-MakeMaker: drop $PORTAGE_TMPDIR from LD_RUN_PATH"
,"- Bug: https://bugs.gentoo.org/105054"
,"0004-Remove-rpath-and-append-LDFLAGS-to-lddlflags.patch"
,"- Remove -rpath and append LDFLAGS to lddlflags"
,"0005-Add-headers-for-opensolaris.patch"
,"- Add headers for opensolaris"
,"0006-List-packaged-patches-in-patchlevel.h.patch"
,"- List packaged patches for perl-5.38.2-r1(perl-5.38.0-patches-1) in patchlevel.h"
,"- Bug: https://bugs.debian.org/567489"
,"0007-Cleanup-PATH-and-shrpenv.patch"
,"- Cleanup PATH and shrpenv"
,"0008-Tweak-enc2xs-to-follow-symlinks-and-ignore-missing-I.patch"
,"- Tweak enc2xs to follow symlinks and ignore missing @INC directories."
,"- Bug: https://bugs.debian.org/290336"
,"0009-darwin-Use-CC-to-link.patch"
,"- darwin: Use $CC to link"
,"- Bug: https://bugs.gentoo.org/297751"
,"0010-Provide-a-sensible-INSTALLDIRS-default-for-modules-i.patch"
,"- Provide a sensible INSTALLDIRS default for modules installed from CPAN."
,"0011-Fix-interix-hints.patch"
,"- Fix interix hints"
,"0012-Set-libperl-soname.patch"
,"- Set libperl soname"
,"- Bug: https://bugs.gentoo.org/286840"
,"0013-Add-etc-perl-to-INC.patch"
,"- Add /etc/perl to @INC"
,"0014-cpan-ExtUtils-MakeMaker-remove-targets-that-generate.patch"
,"- cpan/ExtUtils-MakeMaker: remove targets that generate perllocal.pod"
,"0015-Don-t-force-fstack-protector-on-everyone.patch"
,"- Don't force -fstack-protector on everyone"
,"- Bug: https://bugs.gentoo.org/348557"
,"0016-Do-not-set-custom-CFLAGS-in-cpan-Digest-SHA.patch"
,"- Do not set custom CFLAGS in cpan/Digest-SHA"
,"- Bug: https://bugs.gentoo.org/506818"
,"0017-Configure-Don-t-include-sources-in-usr-local-for-com.patch"
,"- Configure: Don't include sources in /usr/local/ for compiling perl"
,"0018-cpan-IO-Socket-IP-Disable-network-tests.patch"
,"- cpan/IO-Socket-IP: Disable network tests"
,"0019-Fix-EUMM-podlocal-tests.patch"
,"- Fix EUMM podlocal tests"
,"0020-Skip-auto-linking-cl-and-pthread.patch"
,"- Skip auto-linking nsl and cl"
,"- Bug: https://rt.perl.org/Public/Bug/Display.html?id=13148"
,"0021-Disable-porting-tests-which-create-fun-false-failure.patch"
,"- Disable porting tests which create fun false-failures all over travis"
,"0022-Disable-PathTools-tests-which-fails-under-sandboxing.patch"
,"- Disable PathTools tests which fails under sandboxing"
,"- Bug: https://bugs.gentoo.org/645084"
,"0023-Fix-CPAN-FirstTime-defaults-with-nonexisting-site-di.patch"
,"- Fix CPAN::FirstTime defaults with nonexisting site dirs if a parent is writable"
,"- Bug: https://bugs.debian.org/688842"
,"0024-Pass-LD-settings-through-to-subdirectories.patch"
,"- Pass LD settings through to subdirectories"
,"- Bug: https://bugs.debian.org/758471"
,"0025-Respect-umask-during-installation.patch"
,"- Respect umask during installation"
,"0026-Fix-parallel-building.patch"
,"- Fix parallel building"
,"0027-Add-support-for-Dgentoolibdirs-note-hashes-in-uconfi.patch"
,"- Add support for -Dgentoolibdirs"
,"0028-Fix-hashes-in-uconfig.h-hooray.patch"
,"- Fix tests"
